---
name: Bug report
about: Notify the developers of anomalous and incorrect software behavior
title: ''
labels: bug
assignees: ''

---

**Bug Description**
A clear and concise description of what the bug is.

**Full Traceback**
Full traceback of any errors received, if applicable

**Code Sample**
A copy-pastable example if possible

```python
# Your code here

```

**To Reproduce**
Steps to reproduce the problem behavior
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**System (please complete the following information):**
 - OS: [e.g. OSX, Windows, Linux]
 - Compute hardware (e.g. Eagle, AWS)
 - Version [e.g. 0.1]

**Additional context**
Add any other context about the problem here.

**Charge code**
If you are at NREL and fixing this bug is urgent, please provide a charge code for our time.
